==> archimedes-1.2.0.tar.bz2: archimedes-1.2.0/src/GaP.h <==
/* GaP.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 26 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// conduction band calculated using the model : sp3s* (see Vogl)
// data interpolated by a 10-th order polynomial

CB_FULL[GAP][0]=-5.1174e+06;
CB_FULL[GAP][1]=-4.1993e+11;
CB_FULL[GAP][2]=-1.6139e+10;
CB_FULL[GAP][3]=-6.2968e+11;
CB_FULL[GAP][4]=-1.5600e+13;
CB_FULL[GAP][5]=6.0356e+11;
CB_FULL[GAP][6]=-9.5210e+09;
CB_FULL[GAP][7]=7.6197e+07;
CB_FULL[GAP][8]=-2.7319e+05;
CB_FULL[GAP][9]=8.3500e+01;
CB_FULL[GAP][10]=2.8663e+00;

==> archimedes-2.0.0.tar.bz2: archimedes-2.0.0/src/GaP.h <==
/* GaP.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// Parabolic Conduction Band
// 100-direction

CB_FULL[GAP][0]=+3.3288e+22;
CB_FULL[GAP][1]=-1.5431e+21;
CB_FULL[GAP][2]=+2.8974e+19;
CB_FULL[GAP][3]=-2.7841e+17;
CB_FULL[GAP][4]=+1.3844e+15;
CB_FULL[GAP][5]=-2.6703e+12;
CB_FULL[GAP][6]=-4.6291e+09;
CB_FULL[GAP][7]=+3.0069e+07;
CB_FULL[GAP][8]=+1.1525e+07;
CB_FULL[GAP][9]=+2.0468e+01;
CB_FULL[GAP][10]=0.0; //-5.2665e-04;
